ll_lnormparmix: Log-likelihood with respect to xmin
Description
This function evaluates the log-likelihood function with respect to xmin for a mixture of a lognormal and a Pareto r.v.,
assuming to know the numerical values of all the other parameters.
Usage
ll_lnormparmix(x, pi, mu, sigma, alpha, y)
Value
ll numerical value of the log-likelihood function.
Arguments
x
positive scalar: value of xmin where the function is evaluated.
pi
scalar, 0 < pi < 1: mixing weight.
mu
scalar: expected value of the lognormal distribution on the log scale.
sigma
positive scalar: standard deviation of the lognormal distribution on the log scale.